@@ -16,6 +16,8 @@ from sky_api_client.entity import gender  # noqa: F401
 from sky_api_client.entity import gift  # noqa: F401
 from sky_api_client.entity import online_presence  # noqa: F401
 from sky_api_client.entity import phone  # noqa: F401
+from sky_api_client.entity import suffix  # noqa: F401
+from sky_api_client.entity import title  # noqa: F401
 from sky_api_client.entity import relationship  # noqa: F401
 from sky_api_client.entity import table_entry  # noqa: F401
 from sky_api_client.entity import webhook_subscription  # noqa: F401
@@ -25,4 +27,5 @@ from sky_api_client.entity import constituent_education  # noqa: F401
 from sky_api_client.entity import constituent_email_address  # noqa: F401
 from sky_api_client.entity import constituent_online_presence  # noqa: F401
 from sky_api_client.entity import constituent_phone  # noqa: F401
-from sky_api_client.entity import constituent_relationship  # noqa: F401
\ No newline at end of file
+from sky_api_client.entity import constituent_code  # noqa: F401
+from sky_api_client.entity import constituent_relationship  # noqa: F401
